package com.zehong.system.service.impl;

import java.util.List;
import java.util.Map;

import com.zehong.common.core.domain.AjaxResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TLpgGasBottleFilesMapper;
import com.zehong.system.domain.TLpgGasBottleFiles;
import com.zehong.system.service.ITLpgGasBottleFilesService;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

/**
 * 液化石油气-气瓶档案Service业务层处理
 * 
 * @author zehong
 * @date 2024-07-09
 */
@Service
public class TLpgGasBottleFilesServiceImpl implements ITLpgGasBottleFilesService 
{
    @Resource
    private TLpgGasBottleFilesMapper tLpgGasBottleFilesMapper;


    /**
     * 查询液化石油气-气瓶档案
     * 
     * @param fGasBottleFilesId 液化石油气-气瓶档案ID
     * @return 液化石油气-气瓶档案
     */
    @Override
    public TLpgGasBottleFiles selectTLpgGasBottleFilesById(Long fGasBottleFilesId)
    {
        return tLpgGasBottleFilesMapper.selectTLpgGasBottleFilesById(fGasBottleFilesId);
    }

    /**
     * 查询液化石油气-气瓶档案列表
     * 
     * @param tLpgGasBottleFiles 液化石油气-气瓶档案
     * @return 液化石油气-气瓶档案
     */
    @Override
    public List<TLpgGasBottleFiles> selectTLpgGasBottleFilesList(TLpgGasBottleFiles tLpgGasBottleFiles)
    {
        return tLpgGasBottleFilesMapper.selectTLpgGasBottleFilesList(tLpgGasBottleFiles);
    }

    /**
     * 导出
     * @param tLpgGasBottleFiles t
     * @return r
     */
    @Override
    public List<TLpgGasBottleFiles> exportTLpgGasBottleFilesList(TLpgGasBottleFiles tLpgGasBottleFiles) {
        return tLpgGasBottleFilesMapper.exportTLpgGasBottleFilesList(tLpgGasBottleFiles);
    }

    /**
     * 新增液化石油气-气瓶档案
     * 
     * @param tLpgGasBottleFiles 液化石油气-气瓶档案
     * @return 结果
     */
    @Override
    public int insertTLpgGasBottleFiles(TLpgGasBottleFiles tLpgGasBottleFiles)
    {
        return tLpgGasBottleFilesMapper.insertTLpgGasBottleFiles(tLpgGasBottleFiles);
    }

    /**
     * 修改液化石油气-气瓶档案
     * 
     * @param tLpgGasBottleFiles 液化石油气-气瓶档案
     * @return 结果
     */
    @Override
    public int updateTLpgGasBottleFiles(TLpgGasBottleFiles tLpgGasBottleFiles)
    {
        return tLpgGasBottleFilesMapper.updateTLpgGasBottleFiles(tLpgGasBottleFiles);
    }

    /**
     * 批量删除液化石油气-气瓶档案
     * 
     * @param fGasBottleFilesIds 需要删除的液化石油气-气瓶档案ID
     * @return 结果
     */
    @Override
    public int deleteTLpgGasBottleFilesByIds(Long[] fGasBottleFilesIds)
    {
        return tLpgGasBottleFilesMapper.deleteTLpgGasBottleFilesByIds(fGasBottleFilesIds);
    }

    /**
     * 删除液化石油气-气瓶档案信息
     * 
     * @param fGasBottleFilesId 液化石油气-气瓶档案ID
     * @return 结果
     */
    @Override
    public int deleteTLpgGasBottleFilesById(Long fGasBottleFilesId)
    {
        return tLpgGasBottleFilesMapper.deleteTLpgGasBottleFilesById(fGasBottleFilesId);
    }

    /**
     * 气瓶档案导入
     * @param xmbhList data
     * @param updateSupport 是否更新
     * @param response res
     * @return r
     */
    @Override
    public void importLpgGasBottleFilesInfo(List<TLpgGasBottleFiles> xmbhList, boolean updateSupport, HttpServletResponse response) {
        if (xmbhList.size() > 0) {
            tLpgGasBottleFilesMapper.insertBatch(xmbhList);
        }
    }

    /**
     * 第三方对接 创建数据
     * @param list d
     * @return r
     */
    @Override
    public int externalDockingCreateLpgGasBottleFiles(List<TLpgGasBottleFiles> list) {

        return tLpgGasBottleFilesMapper.insertBatch(list);
    }
}
